@@ -32,7 +32,7 @@ sys.path.insert(0, os.path.abspath('../..'))
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 extensions = [
-    'sphinx.ext.autodoc',
+    'sphinxcontrib.apidoc',
     'oslo_config.sphinxext',
     'oslo_config.sphinxconfiggen',
     'openstackdocstheme',
@@ -49,10 +49,17 @@ source_suffix = '.rst'
 master_doc = 'index'
 
 # General information about the project.
-copyright = u'2017, The Networking Baremetal team'
+copyright = '2017, The Networking Baremetal team'
 
-config_generator_config_file = '../../tools/config/networking-baremetal-config-generator.conf'
-sample_config_basename = '_static/ironic_neutron_agent.ini'
+config_generator_config_file = [
+    ('../../tools/config/networking-baremetal-ironic-neutron-agent.conf',
+     '_static/ironic_neutron_agent.ini'),
+    ('../../tools/config/networking-baremetal-common-device-driver-opts.conf',
+     '_static/common_device_driver_opts'),
+    ('../../tools/config/networking-baremetal-netconf-openconfig-driver-opts.conf',
+     '_static/netconf_openconfig_device_driver')
+]
+# sample_config_basename = '_static/ironic_neutron_agent.ini'
 
 # A list of ignored prefixes for module index sorting.
 modindex_common_prefix = ['networking_baremetal.']
@@ -65,7 +72,7 @@ add_function_parentheses = True
 add_module_names = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'native'
 
 # If true, '()' will be appended to :func: etc. cross-reference text.
 add_function_parentheses = True
@@ -77,8 +84,9 @@ add_function_parentheses = True
 html_theme = 'openstackdocs'
 
 # openstackdocstheme options
-repository_name = 'openstack/networking-baremetal'
-use_storyboard = True
+openstackdocs_repo_name = 'openstack/networking-baremetal'
+openstackdocs_pdf_link = True
+openstackdocs_use_storyboard = True
 
 # Output file base name for HTML help builder.
 htmlhelp_basename = 'networking-baremetaldoc'
@@ -91,9 +99,17 @@ latex_use_xindy = False
 latex_documents = [
     ('index',
      'doc-networking-baremetal.tex',
-     u'Networking Baremetal Documentation',
-     u'OpenStack Foundation', 'manual'),
+     'Networking Baremetal Documentation',
+     'OpenStack Foundation', 'manual'),
 ]
 
 # Example configuration for intersphinx: refer to the Python standard library.
 #intersphinx_mapping = {'http://docs.python.org/': None}
+
+# -- sphinxcontrib.apidoc configuration --------------------------------------
+
+apidoc_module_dir = '../../networking_baremetal'
+apidoc_output_dir = 'contributor/api'
+apidoc_excluded_paths = [
+    'tests',
+]
